/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvControlSlice.h"
#include "HvSignalEnvelope.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvMath.h"
#include "HvSignalVar.h"
#include "HvControlDelay.h"
#include "HvControlVar.h"
#include "HvControlBinop.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_gczszUX2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ICJ2RqXK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GP11kyfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CAl6fub8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vOjLRU71_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YsNeYin6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pwurCaZR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MAygh8wX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_59Hezij3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cBZt3Hgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pj1IDRmm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zB819Zvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NdLaoLMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yciCn4tS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tg7wP2c4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FbRv2PXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XVT4nL5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBP7egaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S5K2I1SZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OfQ9TTsH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_R0dyRDkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lt4hC5xw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_k4QZouph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SCssagSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s7hs7Xdr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5SNEp3e0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lk3as85R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VYUkZccj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_yMI2Cw28_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zig2JlU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_luMk4GlB_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lODpsm9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QYyE1ErD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G9sg8bBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tPO2mut4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PoiEWTHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xe32m6C8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qteEkr2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zZOkG0WD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vjw19p2q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ev3X5uKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YkofotUI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_haQKJLV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_e4eBjdkJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3dYneT15_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vHHGPWm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sebDQXLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I1x9afDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FwYlFV8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBdnBwWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_88vreten_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1Mcq8R1C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BLAi2Ap9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rCyHkMt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QUxvmMA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CssYs0uX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7MFeNMAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qwDmHK8M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cT4UT1jV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_8CUkVn00_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buceENEz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_El5Ghcup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TY9y4PwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0U10WIQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ESM3LpWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZkLekb8W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2J6iVKN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6Q2lz2lH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e8McuZGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vOOLnmjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RMjAlvMC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nhU5Dgtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tmcV7HRA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dONh5RZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HYeWAwSK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yyphIzGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VwtXZ1IY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1geEvd3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_54abDm0L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0E7puiO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HFQDgevI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_muD7lvTf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mnKEsOtk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_22dKEgyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_glhrIJZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jWxCES3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_S91T6XWc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_f2Gj2dre_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4hQDocXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zBdXmSeP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ySML8qTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aP54DCez_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UqMQ3Udw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kAi8xsnX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5wSkil58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_x7OyQcjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_joe1CWm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dlmvqE3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IUC4Ku8S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0zvVyJ2W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_E5URYKes_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_VgvhFfjr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9K24j7V4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_laCmpXp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7pqQHoqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AVOVOElC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l2kuNcUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zUnXRdcy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NXW58sIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OLcVWSs7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ddkVlvFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qfJp8KmR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5DVVNCWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XvbOTRII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JCY8emlP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ep3iMmK7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KqnokD3Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zJmz24mC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RyNGOdUo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ULlyqILm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RUdUfa9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z2u8OqJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6gzPC7d6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xn3Tlh5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kpNaBCcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jTYC9Cut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xD7iunjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_B596gPS6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kWhkWjLV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_5Cnd5CWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y2lm5Mbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FpvRDo56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxuPQEF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OL1k6b48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_702TgTfh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0lH7ajwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xiWnIH2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mlf7zlO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ubodoMEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gSVq84Mk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9d9887ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BVkLTCQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xuRxMscU_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_dQwgrZtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bxYFB4qQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WjNBQ8xL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sB8y8hGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YsVipkRK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oCNqJ5Cc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eSGegB9y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J64QQDsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ue1AVBh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HcClWwUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ITQj1kRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cxbRv2j3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sQqZpSy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JaR9DBe7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_p3qoeBgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JOURicOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zebZWDWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XPojP223_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T9QJMdFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFMQ9okt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pxizyAm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2uk97222_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GKilY8Yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KcRw0TrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jh0o0zTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_84UPyr7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OCCNDTqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KP8u54jr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_vwGYDAEF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_njNIllth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8vZ94WtM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PX5wzph5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JMjqS21T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ixWJL594_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6aaDonhp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8OH7IOw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zhGM29bs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qPGKBHDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KJZyGLjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fvNY8TTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cVdbTeYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bRrZeV2r_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_JP8g93YN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MxZQXKeJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AOOJUkk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UhzEDBNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T91v479n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_96chxXyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pfNaM9ri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_knoHDy6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_irjsAFJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ykdZ9mpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KPBzVrKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cQsy0XoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RzLi3O5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKse0k6v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zXbkRNIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WPSZp4nD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7JmGJRQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ug5Jc3np_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qbhUNPdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aaqbm1BQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ii24Izfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o4ZPt9Z6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U7Bul8X6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rze7afYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BjAd66Pm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SJEnxZYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eraoUGZx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c4jAXbo0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nf9dx27u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gbKQEdV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hEm3vegL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x4TiqyQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FaHbeTfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fp911HS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8hcLvFEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X99W8TSC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hsTDKI6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6VJw88s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9ufgwpPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TKd58upE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3WPAFOMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ddeHJAY0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s980HKFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0rDlz3s6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a1xPrM4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aHk2ti5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HnesLRsG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6BPj6x2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pdAsynSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bt5IQ73r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7lGhGY8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZVB4eH3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hZOg5IqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FASCTQDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XtsPvcrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7QvrsioG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wmeW9FcR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1lzOfAcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JlnShxeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_M7TqDM6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yJpUokqE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_8txIuNX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8fcPB9lu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8kCyZOQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gavOtvzw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_d28fBYjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0Zd8iUT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hA0vpe2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5MllVbvl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_h0plYzNA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_erJn4lnu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KkuxiTqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3ldK29WJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UtvLWfyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FyhgiBg6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TCX0gq2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5eQLIXiL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_QJ7TZCIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EyHiyb1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qv3EU4VX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_63Q4DWu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bQr9ZbYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gGSmJNmM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_R3WjskHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_i3U2pxIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wzwdy4Uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_leFpHM92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pQQaL4K9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QsMprVQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zRT7p9CL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zgIERyGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GFjlfolI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5MSHBOvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yI3nS0fY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JHiclQzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DgpzoKGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k3GAYNcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMXnMDKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZJGdanCf_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Reu8BWBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CviFCnXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tXbN3sMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wALOm2vh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cZbrNCvt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5GWfXZTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6UyChtFV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bs9NbCed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PzBfWhk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ivodHEDB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o6qNQI69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eCqBnIGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JmToApJG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L82OIUzB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qYZEk4Ag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Rq0rtx9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_940ByHM5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_rTXjjUdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XklQFPRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9CPvLXHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fA5gCvXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TAOH50bj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fr9mumha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sxUr6pip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pMLuWP7X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZH1PoFTh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lpujr0J9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_saXONVEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TwU0WHjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvrSrHmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w9WpWxce_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G3T5NtKI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IxwkYv2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WDOsi7Ap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_idMWrrqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O8GGQpFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_io3g5Mh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PAL9DjyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xIXpmbV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4AwbWbOw_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ETHkvpnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OHaX56D7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VkhWCZ1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_23OJi99Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o9QI4pZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_txJqfT52_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYDAgFL4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_awmK3MqV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_te6tgGm4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RiwkeQGU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R2O09AWO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2oJs8Qb2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YfqYQONa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oaBEP1SD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_a6rvpMvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z3ZgwlvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GhMfdSJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xwoO3YTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a3QPy6yB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UKp7Tecr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zF9fisgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BPy93xR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P85VLC09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MSojzOwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0C87qhjK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HIR4fAqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A0ZDaedn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HkwyOU02_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_AJQz00FW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yyo1It7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yx1Fq4hX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JpU4wjeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LOjwNXIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aVgI6wnx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1YiOqRdK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s0yRjlbc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Kh4p550s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nFn2UPUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0iYju8H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Hxeg7pol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4SXsJCNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_24aDwNGV_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Tegqfuvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XWHRFJ4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bwrsL4ii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d1RyVART_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GSCUR3z0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3QkCaGyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v6xVghB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d0zo78Qv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sVTgfxjf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b4VUJPag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QBzDDPfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UqpW5c2V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_T86f4iJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7VSdQVol_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_K7YDHzu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fDWFp5V3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3yQr4yOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kFHynBdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3L6zm4KL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rSilo2TO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5pag02G1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iN8dBt2m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IRjiyJJJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pKR9dj7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iMOSQRaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_57vkF1UH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tJhcPha0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_wQAFhCiL_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_RkfWWBbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_amMYG97h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iVaY1Z4i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kuXDKdmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r86jkJcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xc8XcR0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bggxShmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c5F70y1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MXwwjg6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DcbL52gR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ye2S9yPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bwn7mFdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0uIn51nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AszuRRm6_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_tl98dd5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8WVhSM9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SSkaTJws_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sZS5FoyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zeggDrpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sRISsPOl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QxdoFxaT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ORciXLy4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rcPjiHNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uz4d4f3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3YCb4MpP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_l7Sdbb1k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wOG03zqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7z4pJgnx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1p4wFG2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LOQhuOdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DoMFvGgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_McRaNmGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AFUNLAAd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2zW3pEtn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_53kUouuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ecG6URXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AJMduBhi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NyLMAD5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9gPLjfMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_foGTEiue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g41BihN6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_khbqvWG4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wuvvtlaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MMlTu9kr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3tOTIPkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4IDvIkri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W6Sr1juB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N8HSXBrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8NCmXsiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AviaBOuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v5Pp0IvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0aCIr7tt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AIfsuI32_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0RZYnIAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4jSVoP2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Px2XLX1W_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Ynp2dfaf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ju9SDVxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F4JurEmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_REW64mnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2MlSvpXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VaMfCP0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s3zKtUw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zt4EQMpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DGjHgwxu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nqdebG2p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LdAtIoYR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_JpcmP4Sn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nTlUAdfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_d2WEEj04_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7iyLxyAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x7yWnJWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UBogHNId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hUhhHxXW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dN550gEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0psgkwfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dj0tAcbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pJsCi6fR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Tf1oMUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lcr6lq0u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m3X7mdu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yEI4onh7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HokBdisj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rduwKBDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L8i2J3Qs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_63B15Y3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ry9gbTbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_unjEMi9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DbyNPP06_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_otY3q67E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kIRVTgUL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S2X5akGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wHhzEcOg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4SFooikL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0D04XpVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F1CTvsTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T96slg4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BXMgg4GH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nIqGBFKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ptwoSCMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iO6lpQtz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LqTccBml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C2pJCCCT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CZI3SF8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PJ56JDUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m2MEtVSN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U6pVdYAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZzjAAu2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Go3dWcw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rB6H41I2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_74IglVMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3R95b1o2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1YjdyeGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6hlbnJBg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZZV8WYAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S4Rpyvkv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dXjiq98G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FVspfoli_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fhEbINrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cJV9aVVH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7nKVj0La_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NkgUaol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mnw64EVU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QzBjHmHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WqNMyg3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x7MxUScd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_33eL3Djp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kUo6nNi4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_juMZb31f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2Gji1pdu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_l2ko9CqD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_A0IjdT0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N54EWtAq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ybG9vYxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fpY9N4VE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_QF3O3WQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gNzG9S7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RZiJtV95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Fv5hYsCy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vvjNRWHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XkuptYd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_S8KBHh94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ZtspIR38_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_kI1ay4s5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RyOnuE9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qKeu4eiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ykyUqMEh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_ozLQIPvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2ilVVGvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e9pWi1zb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aLBKb1Px_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rd0oOUEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2vCI0WIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_pnOBb9pp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_wb2g4Nxp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AkcM5CZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PVSskAxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vpY7dpoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z1dJzEfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W7jJlObl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDVRg5A5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GCpg6btz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vVhNqojX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OF1tZA8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EwjvHpvJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5XFqIm5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O6NAvV1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_11oGkwkY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3aqGOn4f_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AHHqoHzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TGFIx6mA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hix881if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6wmzxIvB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9RF6NLPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rk6KfwGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mv8J2KmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GLXUCA2c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I1PlDqK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BnlIUOs1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q1QxpOPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6JSDElYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eBsHyiW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_y0yeoATb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bfJ2kPId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6iCtxyKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7r0KKm9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7jl3LHN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MISAAxhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c7QzeRcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IcsxJYdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1NMrkca5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rLIB0a7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_57liT5Vm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rpdnjwsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vd4RWvKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KDHuuBfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x2DIPTla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qPQvU4ZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FAZIntpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vqgsu7xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_v9F8KShz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YCtHfCPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_J2rOmtNo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qcx2S4Ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zrnA03Zc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vxrZDCPl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ehoHayXH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wSYfhpLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qFr5dh61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LN32hqag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_htZVxfkW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zno71j5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_I60sX4Ap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_GunYKtOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BoZk5pq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LZnyUgU4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7cJPFLJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IDjPrjDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EI6U3bBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wdUbwTkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_9EGUOndU;
  SignalLine sLine_sTNKlyB0;
  SignalLine sLine_zPbDm5uu;
  SignalLine sLine_q8s90BvT;
  SignalLine sLine_z4qlIadb;
  SignalLine sLine_JMa0S9kL;
  SignalLine sLine_tkTcaLme;
  SignalLine sLine_qazBtqO8;
  SignalLine sLine_uD9lu5XG;
  SignalLine sLine_4Jn6oseC;
  SignalLine sLine_ize64v2W;
  SignalLine sLine_T6FXg4pc;
  SignalEnvelope sEnv_R3WjskHg;
  SignalEnvelope sEnv_i3U2pxIk;
  SignalLine sLine_c8yfmAjs;
  SignalLine sLine_I1hINQIC;
  SignalLine sLine_awocrIq2;
  SignalLine sLine_m2cITV4K;
  SignalLine sLine_fHwuOw26;
  SignalLine sLine_EgpyUGUN;
  SignalLine sLine_hjq5E0y3;
  SignalLine sLine_xZTykW3a;
  SignalLine sLine_NbKpmynk;
  SignalLine sLine_CyMiW5Ty;
  SignalLine sLine_aLIADwUb;
  SignalLine sLine_EJfQ5Clt;
  SignalLine sLine_R3BiC2IY;
  SignalLine sLine_rGACZLl2;
  SignalLine sLine_418mjXL4;
  SignalLine sLine_exEPKAqc;
  SignalLine sLine_kW5mjH5O;
  SignalLine sLine_SpwHMafU;
  SignalEnvelope sEnv_pnOBb9pp;
  SignalEnvelope sEnv_wb2g4Nxp;
  SignalLine sLine_u64qlEzX;
  SignalLine sLine_Tk9dGPwA;
  SignalLine sLine_d55QO3QF;
  SignalLine sLine_dugLJFVG;
  SignalLine sLine_aFqNjtdx;
  SignalLine sLine_Z3TgquWG;
  SignalLine sLine_mdKse8CY;
  SignalLine sLine_XX9ryO8W;
  ControlVar cVar_gczszUX2;
  ControlBinop cBinop_ICJ2RqXK;
  ControlBinop cBinop_GP11kyfY;
  ControlBinop cBinop_CAl6fub8;
  ControlBinop cBinop_vOjLRU71;
  ControlBinop cBinop_MAygh8wX;
  ControlBinop cBinop_cBZt3Hgf;
  ControlBinop cBinop_pj1IDRmm;
  ControlBinop cBinop_zB819Zvq;
  ControlVar cVar_NdLaoLMQ;
  ControlVar cVar_yciCn4tS;
  ControlVar cVar_Tg7wP2c4;
  ControlVar cVar_FbRv2PXe;
  ControlVar cVar_XVT4nL5B;
  ControlBinop cBinop_LBP7egaS;
  ControlVar cVar_OfQ9TTsH;
  ControlVar cVar_R0dyRDkC;
  ControlIf cIf_yMI2Cw28;
  ControlIf cIf_zig2JlU2;
  ControlDelay cDelay_lODpsm9O;
  ControlBinop cBinop_tPO2mut4;
  ControlBinop cBinop_PoiEWTHe;
  ControlIf cIf_haQKJLV2;
  ControlIf cIf_e4eBjdkJ;
  ControlDelay cDelay_vHHGPWm8;
  ControlBinop cBinop_FwYlFV8V;
  ControlBinop cBinop_hBdnBwWx;
  ControlIf cIf_7MFeNMAL;
  ControlIf cIf_qwDmHK8M;
  ControlDelay cDelay_8CUkVn00;
  ControlBinop cBinop_TY9y4PwP;
  ControlBinop cBinop_0U10WIQy;
  ControlIf cIf_RMjAlvMC;
  ControlIf cIf_nhU5Dgtw;
  ControlDelay cDelay_dONh5RZq;
  ControlBinop cBinop_VwtXZ1IY;
  ControlBinop cBinop_1geEvd3v;
  ControlIf cIf_glhrIJZU;
  ControlIf cIf_jWxCES3A;
  ControlDelay cDelay_f2Gj2dre;
  ControlBinop cBinop_ySML8qTM;
  ControlBinop cBinop_aP54DCez;
  ControlIf cIf_IUC4Ku8S;
  ControlIf cIf_0zvVyJ2W;
  ControlDelay cDelay_VgvhFfjr;
  ControlBinop cBinop_7pqQHoqn;
  ControlBinop cBinop_AVOVOElC;
  ControlIf cIf_5DVVNCWN;
  ControlIf cIf_XvbOTRII;
  ControlDelay cDelay_Ep3iMmK7;
  ControlBinop cBinop_RyNGOdUo;
  ControlBinop cBinop_ULlyqILm;
  ControlIf cIf_xD7iunjh;
  ControlIf cIf_B596gPS6;
  ControlDelay cDelay_5Cnd5CWp;
  ControlBinop cBinop_rxuPQEF2;
  ControlBinop cBinop_OL1k6b48;
  ControlIf cIf_9d9887ih;
  ControlIf cIf_BVkLTCQy;
  ControlDelay cDelay_dQwgrZtX;
  ControlBinop cBinop_sB8y8hGM;
  ControlBinop cBinop_YsVipkRK;
  ControlIf cIf_cxbRv2j3;
  ControlIf cIf_sQqZpSy3;
  ControlDelay cDelay_p3qoeBgc;
  ControlBinop cBinop_XPojP223;
  ControlBinop cBinop_T9QJMdFH;
  ControlIf cIf_84UPyr7s;
  ControlIf cIf_OCCNDTqR;
  ControlDelay cDelay_vwGYDAEF;
  ControlBinop cBinop_PX5wzph5;
  ControlBinop cBinop_JMjqS21T;
  ControlIf cIf_fvNY8TTk;
  ControlIf cIf_cVdbTeYt;
  ControlDelay cDelay_JP8g93YN;
  ControlBinop cBinop_UhzEDBNz;
  ControlBinop cBinop_T91v479n;
  SignalVarf sVarf_MICFFoUG;
  SignalVarf sVarf_og96IjJP;
  SignalVarf sVarf_kYu3u3mF;
  SignalVarf sVarf_WnwXWvAV;
  SignalVarf sVarf_1CNtFHgP;
  SignalVarf sVarf_OyG3kkGg;
  SignalVarf sVarf_W2Wdjbc5;
  SignalVarf sVarf_tK1Va8Km;
  ControlVar cVar_7QvrsioG;
  ControlSlice cSlice_1lzOfAcP;
  ControlVar cVar_JlnShxeG;
  ControlSlice cSlice_8txIuNX1;
  ControlVar cVar_8fcPB9lu;
  ControlSlice cSlice_d28fBYjW;
  ControlVar cVar_0Zd8iUT7;
  ControlSlice cSlice_h0plYzNA;
  ControlVar cVar_erJn4lnu;
  ControlSlice cSlice_UtvLWfyD;
  ControlVar cVar_FyhgiBg6;
  ControlDelay cDelay_QJ7TZCIG;
  ControlVar cVar_63Q4DWu4;
  ControlIf cIf_bQr9ZbYN;
  ControlIf cIf_gGSmJNmM;
  ControlBinop cBinop_wzwdy4Uk;
  ControlBinop cBinop_pQQaL4K9;
  ControlBinop cBinop_QsMprVQj;
  ControlBinop cBinop_GFjlfolI;
  ControlBinop cBinop_yI3nS0fY;
  ControlSlice cSlice_Reu8BWBE;
  ControlVar cVar_CviFCnXM;
  SignalVarf sVarf_Hq7gaEfM;
  SignalVarf sVarf_Zpq8BXOV;
  SignalVarf sVarf_BxKHiCWg;
  SignalVarf sVarf_1XkLUkCk;
  SignalVarf sVarf_1Eomvcyg;
  SignalVarf sVarf_Q3EXpJj9;
  ControlBinop cBinop_5GWfXZTx;
  ControlBinop cBinop_JmToApJG;
  ControlVar cVar_qYZEk4Ag;
  ControlVar cVar_Rq0rtx9z;
  ControlIf cIf_sxUr6pip;
  ControlIf cIf_pMLuWP7X;
  ControlDelay cDelay_lpujr0J9;
  ControlBinop cBinop_IvrSrHmn;
  ControlBinop cBinop_w9WpWxce;
  ControlIf cIf_PAL9DjyC;
  ControlIf cIf_xIXpmbV5;
  ControlDelay cDelay_ETHkvpnm;
  ControlBinop cBinop_23OJi99Y;
  ControlBinop cBinop_o9QI4pZl;
  ControlIf cIf_2oJs8Qb2;
  ControlIf cIf_YfqYQONa;
  ControlDelay cDelay_a6rvpMvA;
  ControlBinop cBinop_xwoO3YTY;
  ControlBinop cBinop_a3QPy6yB;
  ControlIf cIf_HIR4fAqC;
  ControlIf cIf_A0ZDaedn;
  ControlDelay cDelay_AJQz00FW;
  ControlBinop cBinop_JpU4wjeY;
  ControlBinop cBinop_LOjwNXIJ;
  ControlIf cIf_Hxeg7pol;
  ControlIf cIf_4SXsJCNM;
  ControlDelay cDelay_Tegqfuvf;
  ControlBinop cBinop_d1RyVART;
  ControlBinop cBinop_GSCUR3z0;
  ControlIf cIf_UqpW5c2V;
  ControlIf cIf_T86f4iJe;
  ControlDelay cDelay_K7YDHzu7;
  ControlBinop cBinop_kFHynBdB;
  ControlBinop cBinop_3L6zm4KL;
  ControlIf cIf_57vkF1UH;
  ControlIf cIf_tJhcPha0;
  ControlDelay cDelay_RkfWWBbj;
  ControlBinop cBinop_kuXDKdmd;
  ControlBinop cBinop_r86jkJcf;
  ControlIf cIf_bwn7mFdB;
  ControlIf cIf_0uIn51nR;
  ControlDelay cDelay_tl98dd5z;
  ControlBinop cBinop_sZS5FoyM;
  ControlBinop cBinop_zeggDrpt;
  ControlIf cIf_l7Sdbb1k;
  ControlIf cIf_wOG03zqN;
  ControlDelay cDelay_1p4wFG2i;
  ControlBinop cBinop_McRaNmGc;
  ControlBinop cBinop_AFUNLAAd;
  ControlIf cIf_foGTEiue;
  ControlIf cIf_g41BihN6;
  ControlDelay cDelay_wuvvtlaJ;
  ControlBinop cBinop_4IDvIkri;
  ControlBinop cBinop_W6Sr1juB;
  ControlIf cIf_0RZYnIAT;
  ControlIf cIf_4jSVoP2s;
  ControlDelay cDelay_Ynp2dfaf;
  ControlBinop cBinop_REW64mnZ;
  ControlBinop cBinop_2MlSvpXr;
  ControlIf cIf_JpcmP4Sn;
  ControlIf cIf_nTlUAdfa;
  ControlDelay cDelay_7iyLxyAS;
  ControlBinop cBinop_hUhhHxXW;
  ControlBinop cBinop_dN550gEJ;
  SignalVarf sVarf_sAmX5Ntb;
  SignalVarf sVarf_gq6f9FEF;
  SignalVarf sVarf_K1WRTEG7;
  SignalVarf sVarf_UnwcyMyj;
  SignalVarf sVarf_vJqiAhxP;
  SignalVarf sVarf_Nor596eu;
  SignalVarf sVarf_ru1dfGpD;
  SignalVarf sVarf_lLIcmiaY;
  ControlVar cVar_x7MxUScd;
  ControlSlice cSlice_kUo6nNi4;
  ControlVar cVar_juMZb31f;
  ControlSlice cSlice_A0IjdT0O;
  ControlVar cVar_N54EWtAq;
  ControlSlice cSlice_QF3O3WQ0;
  ControlVar cVar_gNzG9S7W;
  ControlSlice cSlice_vvjNRWHF;
  ControlVar cVar_XkuptYd5;
  ControlSlice cSlice_kI1ay4s5;
  ControlVar cVar_RyOnuE9o;
  ControlDelay cDelay_ozLQIPvX;
  ControlVar cVar_aLBKb1Px;
  ControlIf cIf_rd0oOUEO;
  ControlIf cIf_2vCI0WIM;
  ControlBinop cBinop_AkcM5CZQ;
  ControlBinop cBinop_vpY7dpoU;
  ControlBinop cBinop_z1dJzEfl;
  ControlBinop cBinop_GCpg6btz;
  ControlBinop cBinop_OF1tZA8V;
  ControlSlice cSlice_AHHqoHzF;
  ControlVar cVar_TGFIx6mA;
  SignalVarf sVarf_AV6czhmB;
  SignalVarf sVarf_UWPVx5g6;
  SignalVarf sVarf_SkuZZTHm;
  SignalVarf sVarf_TUv1AaSE;
  SignalVarf sVarf_r45RSQJv;
  SignalVarf sVarf_thkcnA1v;
  ControlBinop cBinop_Rk6KfwGw;
  ControlBinop cBinop_eBsHyiW3;
  ControlVar cVar_bfJ2kPId;
  SignalVarf sVarf_mm89ORnp;
  SignalVarf sVarf_pMT3tlZK;
  SignalVarf sVarf_YswIQyvA;
  SignalVarf sVarf_hPEvBNeB;
  ControlBinop cBinop_IcsxJYdW;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
