/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_9EGUOndU);
  numBytes += sLine_init(&sLine_sTNKlyB0);
  numBytes += sLine_init(&sLine_zPbDm5uu);
  numBytes += sLine_init(&sLine_q8s90BvT);
  numBytes += sLine_init(&sLine_z4qlIadb);
  numBytes += sLine_init(&sLine_JMa0S9kL);
  numBytes += sLine_init(&sLine_tkTcaLme);
  numBytes += sLine_init(&sLine_qazBtqO8);
  numBytes += sLine_init(&sLine_uD9lu5XG);
  numBytes += sLine_init(&sLine_4Jn6oseC);
  numBytes += sLine_init(&sLine_ize64v2W);
  numBytes += sLine_init(&sLine_T6FXg4pc);
  numBytes += sEnv_init(&sEnv_R3WjskHg, 512, 256);
  numBytes += sEnv_init(&sEnv_i3U2pxIk, 512, 256);
  numBytes += sLine_init(&sLine_c8yfmAjs);
  numBytes += sLine_init(&sLine_I1hINQIC);
  numBytes += sLine_init(&sLine_awocrIq2);
  numBytes += sLine_init(&sLine_m2cITV4K);
  numBytes += sLine_init(&sLine_fHwuOw26);
  numBytes += sLine_init(&sLine_EgpyUGUN);
  numBytes += sLine_init(&sLine_hjq5E0y3);
  numBytes += sLine_init(&sLine_xZTykW3a);
  numBytes += sLine_init(&sLine_NbKpmynk);
  numBytes += sLine_init(&sLine_CyMiW5Ty);
  numBytes += sLine_init(&sLine_aLIADwUb);
  numBytes += sLine_init(&sLine_EJfQ5Clt);
  numBytes += sLine_init(&sLine_R3BiC2IY);
  numBytes += sLine_init(&sLine_rGACZLl2);
  numBytes += sLine_init(&sLine_418mjXL4);
  numBytes += sLine_init(&sLine_exEPKAqc);
  numBytes += sLine_init(&sLine_kW5mjH5O);
  numBytes += sLine_init(&sLine_SpwHMafU);
  numBytes += sEnv_init(&sEnv_pnOBb9pp, 512, 256);
  numBytes += sEnv_init(&sEnv_wb2g4Nxp, 512, 256);
  numBytes += sLine_init(&sLine_u64qlEzX);
  numBytes += sLine_init(&sLine_Tk9dGPwA);
  numBytes += sLine_init(&sLine_d55QO3QF);
  numBytes += sLine_init(&sLine_dugLJFVG);
  numBytes += sLine_init(&sLine_aFqNjtdx);
  numBytes += sLine_init(&sLine_Z3TgquWG);
  numBytes += sLine_init(&sLine_mdKse8CY);
  numBytes += sLine_init(&sLine_XX9ryO8W);
  numBytes += cVar_init_f(&cVar_gczszUX2, 0.0f);
  numBytes += cVar_init_f(&cVar_NdLaoLMQ, 0.0f);
  numBytes += cVar_init_f(&cVar_yciCn4tS, 0.0f);
  numBytes += cVar_init_f(&cVar_Tg7wP2c4, 0.0f);
  numBytes += cVar_init_f(&cVar_FbRv2PXe, 0.0f);
  numBytes += cVar_init_f(&cVar_XVT4nL5B, 1.0f);
  numBytes += cVar_init_f(&cVar_OfQ9TTsH, 0.0f);
  numBytes += cVar_init_f(&cVar_R0dyRDkC, 0.0f);
  numBytes += cIf_init(&cIf_yMI2Cw28, false);
  numBytes += cIf_init(&cIf_zig2JlU2, false);
  numBytes += cDelay_init(this, &cDelay_lODpsm9O, 10.0f);
  numBytes += cIf_init(&cIf_haQKJLV2, false);
  numBytes += cIf_init(&cIf_e4eBjdkJ, false);
  numBytes += cDelay_init(this, &cDelay_vHHGPWm8, 10.0f);
  numBytes += cIf_init(&cIf_7MFeNMAL, false);
  numBytes += cIf_init(&cIf_qwDmHK8M, false);
  numBytes += cDelay_init(this, &cDelay_8CUkVn00, 10.0f);
  numBytes += cIf_init(&cIf_RMjAlvMC, false);
  numBytes += cIf_init(&cIf_nhU5Dgtw, false);
  numBytes += cDelay_init(this, &cDelay_dONh5RZq, 10.0f);
  numBytes += cIf_init(&cIf_glhrIJZU, false);
  numBytes += cIf_init(&cIf_jWxCES3A, false);
  numBytes += cDelay_init(this, &cDelay_f2Gj2dre, 10.0f);
  numBytes += cIf_init(&cIf_IUC4Ku8S, false);
  numBytes += cIf_init(&cIf_0zvVyJ2W, false);
  numBytes += cDelay_init(this, &cDelay_VgvhFfjr, 10.0f);
  numBytes += cIf_init(&cIf_5DVVNCWN, false);
  numBytes += cIf_init(&cIf_XvbOTRII, false);
  numBytes += cDelay_init(this, &cDelay_Ep3iMmK7, 10.0f);
  numBytes += cIf_init(&cIf_xD7iunjh, false);
  numBytes += cIf_init(&cIf_B596gPS6, false);
  numBytes += cDelay_init(this, &cDelay_5Cnd5CWp, 10.0f);
  numBytes += cIf_init(&cIf_9d9887ih, false);
  numBytes += cIf_init(&cIf_BVkLTCQy, false);
  numBytes += cDelay_init(this, &cDelay_dQwgrZtX, 10.0f);
  numBytes += cIf_init(&cIf_cxbRv2j3, false);
  numBytes += cIf_init(&cIf_sQqZpSy3, false);
  numBytes += cDelay_init(this, &cDelay_p3qoeBgc, 10.0f);
  numBytes += cIf_init(&cIf_84UPyr7s, false);
  numBytes += cIf_init(&cIf_OCCNDTqR, false);
  numBytes += cDelay_init(this, &cDelay_vwGYDAEF, 10.0f);
  numBytes += cIf_init(&cIf_fvNY8TTk, false);
  numBytes += cIf_init(&cIf_cVdbTeYt, false);
  numBytes += cDelay_init(this, &cDelay_JP8g93YN, 10.0f);
  numBytes += sVarf_init(&sVarf_MICFFoUG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_og96IjJP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kYu3u3mF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WnwXWvAV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1CNtFHgP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OyG3kkGg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_W2Wdjbc5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tK1Va8Km, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_7QvrsioG, 0.0f);
  numBytes += cSlice_init(&cSlice_1lzOfAcP, 1, -1);
  numBytes += cVar_init_f(&cVar_JlnShxeG, 1.0f);
  numBytes += cSlice_init(&cSlice_8txIuNX1, 1, -1);
  numBytes += cVar_init_f(&cVar_8fcPB9lu, 0.0f);
  numBytes += cSlice_init(&cSlice_d28fBYjW, 1, -1);
  numBytes += cVar_init_f(&cVar_0Zd8iUT7, 512.0f);
  numBytes += cSlice_init(&cSlice_h0plYzNA, 1, -1);
  numBytes += cVar_init_f(&cVar_erJn4lnu, 1.0f);
  numBytes += cSlice_init(&cSlice_UtvLWfyD, 1, -1);
  numBytes += cVar_init_f(&cVar_FyhgiBg6, 1.0f);
  numBytes += cDelay_init(this, &cDelay_QJ7TZCIG, 20.0f);
  numBytes += cVar_init_f(&cVar_63Q4DWu4, 0.0f);
  numBytes += cIf_init(&cIf_bQr9ZbYN, false);
  numBytes += cIf_init(&cIf_gGSmJNmM, false);
  numBytes += cBinop_init(&cBinop_wzwdy4Uk, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Reu8BWBE, 1, -1);
  numBytes += cVar_init_f(&cVar_CviFCnXM, 0.0f);
  numBytes += sVarf_init(&sVarf_Hq7gaEfM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zpq8BXOV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BxKHiCWg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1XkLUkCk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Eomvcyg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Q3EXpJj9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_qYZEk4Ag, 0.0f);
  numBytes += cVar_init_f(&cVar_Rq0rtx9z, 0.0f);
  numBytes += cIf_init(&cIf_sxUr6pip, false);
  numBytes += cIf_init(&cIf_pMLuWP7X, false);
  numBytes += cDelay_init(this, &cDelay_lpujr0J9, 10.0f);
  numBytes += cIf_init(&cIf_PAL9DjyC, false);
  numBytes += cIf_init(&cIf_xIXpmbV5, false);
  numBytes += cDelay_init(this, &cDelay_ETHkvpnm, 10.0f);
  numBytes += cIf_init(&cIf_2oJs8Qb2, false);
  numBytes += cIf_init(&cIf_YfqYQONa, false);
  numBytes += cDelay_init(this, &cDelay_a6rvpMvA, 10.0f);
  numBytes += cIf_init(&cIf_HIR4fAqC, false);
  numBytes += cIf_init(&cIf_A0ZDaedn, false);
  numBytes += cDelay_init(this, &cDelay_AJQz00FW, 10.0f);
  numBytes += cIf_init(&cIf_Hxeg7pol, false);
  numBytes += cIf_init(&cIf_4SXsJCNM, false);
  numBytes += cDelay_init(this, &cDelay_Tegqfuvf, 10.0f);
  numBytes += cIf_init(&cIf_UqpW5c2V, false);
  numBytes += cIf_init(&cIf_T86f4iJe, false);
  numBytes += cDelay_init(this, &cDelay_K7YDHzu7, 10.0f);
  numBytes += cIf_init(&cIf_57vkF1UH, false);
  numBytes += cIf_init(&cIf_tJhcPha0, false);
  numBytes += cDelay_init(this, &cDelay_RkfWWBbj, 10.0f);
  numBytes += cIf_init(&cIf_bwn7mFdB, false);
  numBytes += cIf_init(&cIf_0uIn51nR, false);
  numBytes += cDelay_init(this, &cDelay_tl98dd5z, 10.0f);
  numBytes += cIf_init(&cIf_l7Sdbb1k, false);
  numBytes += cIf_init(&cIf_wOG03zqN, false);
  numBytes += cDelay_init(this, &cDelay_1p4wFG2i, 10.0f);
  numBytes += cIf_init(&cIf_foGTEiue, false);
  numBytes += cIf_init(&cIf_g41BihN6, false);
  numBytes += cDelay_init(this, &cDelay_wuvvtlaJ, 10.0f);
  numBytes += cIf_init(&cIf_0RZYnIAT, false);
  numBytes += cIf_init(&cIf_4jSVoP2s, false);
  numBytes += cDelay_init(this, &cDelay_Ynp2dfaf, 10.0f);
  numBytes += cIf_init(&cIf_JpcmP4Sn, false);
  numBytes += cIf_init(&cIf_nTlUAdfa, false);
  numBytes += cDelay_init(this, &cDelay_7iyLxyAS, 10.0f);
  numBytes += sVarf_init(&sVarf_sAmX5Ntb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gq6f9FEF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_K1WRTEG7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UnwcyMyj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vJqiAhxP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nor596eu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ru1dfGpD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lLIcmiaY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_x7MxUScd, 0.0f);
  numBytes += cSlice_init(&cSlice_kUo6nNi4, 1, -1);
  numBytes += cVar_init_f(&cVar_juMZb31f, 1.0f);
  numBytes += cSlice_init(&cSlice_A0IjdT0O, 1, -1);
  numBytes += cVar_init_f(&cVar_N54EWtAq, 0.0f);
  numBytes += cSlice_init(&cSlice_QF3O3WQ0, 1, -1);
  numBytes += cVar_init_f(&cVar_gNzG9S7W, 512.0f);
  numBytes += cSlice_init(&cSlice_vvjNRWHF, 1, -1);
  numBytes += cVar_init_f(&cVar_XkuptYd5, 1.0f);
  numBytes += cSlice_init(&cSlice_kI1ay4s5, 1, -1);
  numBytes += cVar_init_f(&cVar_RyOnuE9o, 1.0f);
  numBytes += cDelay_init(this, &cDelay_ozLQIPvX, 20.0f);
  numBytes += cVar_init_f(&cVar_aLBKb1Px, 0.0f);
  numBytes += cIf_init(&cIf_rd0oOUEO, false);
  numBytes += cIf_init(&cIf_2vCI0WIM, false);
  numBytes += cBinop_init(&cBinop_AkcM5CZQ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_AHHqoHzF, 1, -1);
  numBytes += cVar_init_f(&cVar_TGFIx6mA, 0.0f);
  numBytes += sVarf_init(&sVarf_AV6czhmB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UWPVx5g6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SkuZZTHm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TUv1AaSE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r45RSQJv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_thkcnA1v, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bfJ2kPId, 0.0f);
  numBytes += sVarf_init(&sVarf_mm89ORnp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pMT3tlZK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YswIQyvA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hPEvBNeB, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_R3WjskHg);
  sEnv_free(&sEnv_i3U2pxIk);
  sEnv_free(&sEnv_pnOBb9pp);
  sEnv_free(&sEnv_wb2g4Nxp);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J2rOmtNo_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vxrZDCPl_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wdUbwTkA_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zrnA03Zc_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YCtHfCPS_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ehoHayXH_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v9F8KShz_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vqgsu7xh_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LN32hqag_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wSYfhpLs_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I60sX4Ap_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zno71j5g_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qFr5dh61_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_htZVxfkW_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LZnyUgU4_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GunYKtOY_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EI6U3bBE_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IDjPrjDW_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BoZk5pq3_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7cJPFLJq_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qcx2S4Ty_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_gczszUX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MISAAxhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_ICJ2RqXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GP11kyfY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GP11kyfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_CAl6fub8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CAl6fub8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_vOjLRU71_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vOjLRU71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YsNeYin6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pwurCaZR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_YsNeYin6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MAygh8wX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pwurCaZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_59Hezij3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_MAygh8wX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pj1IDRmm_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_59Hezij3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_cBZt3Hgf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_cBZt3Hgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zB819Zvq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pj1IDRmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6iCtxyKU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_zB819Zvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7r0KKm9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_NdLaoLMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7jl3LHN0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_yciCn4tS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1NMrkca5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Tg7wP2c4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c7QzeRcP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_FbRv2PXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rLIB0a7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_XVT4nL5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LBP7egaS_sendMessage);
  cMsg_57liT5Vm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_LBP7egaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XVT4nL5B, 1, m, &cVar_XVT4nL5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_S5K2I1SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rpdnjwsA_sendMessage(_c, 0, m);
  cMsg_vd4RWvKd_sendMessage(_c, 0, m);
  cMsg_KDHuuBfj_sendMessage(_c, 0, m);
  cMsg_FAZIntpJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_OfQ9TTsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wALOm2vh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_R0dyRDkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cZbrNCvt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_lt4hC5xw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k4QZouph_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SCssagSZ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s7hs7Xdr_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5SNEp3e0_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lk3as85R_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VYUkZccj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_k4QZouph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQsy0XoP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_SCssagSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RzLi3O5r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_s7hs7Xdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKse0k6v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_5SNEp3e0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zXbkRNIq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_lk3as85R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WPSZp4nD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_VYUkZccj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7JmGJRQG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_yMI2Cw28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YkofotUI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zig2JlU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ev3X5uKE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_luMk4GlB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QYyE1ErD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QYyE1ErD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lODpsm9O, 1, m, &cDelay_lODpsm9O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G9sg8bBC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lODpsm9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lODpsm9O, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yMI2Cw28, 0, m, &cIf_yMI2Cw28_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QYyE1ErD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lODpsm9O, 0, m, &cDelay_lODpsm9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_G9sg8bBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lODpsm9O, 0, m, &cDelay_lODpsm9O_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_tPO2mut4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zZOkG0WD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vjw19p2q_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PoiEWTHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xe32m6C8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qteEkr2n_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Xe32m6C8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yMI2Cw28, 1, m, &cIf_yMI2Cw28_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qteEkr2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_luMk4GlB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zZOkG0WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zig2JlU2, 1, m, &cIf_zig2JlU2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_vjw19p2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zig2JlU2, 0, m, &cIf_zig2JlU2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ev3X5uKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8s90BvT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_YkofotUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8s90BvT, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_haQKJLV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CssYs0uX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_e4eBjdkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QUxvmMA0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_3dYneT15_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sebDQXLP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sebDQXLP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vHHGPWm8, 1, m, &cDelay_vHHGPWm8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I1x9afDD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vHHGPWm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vHHGPWm8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_haQKJLV2, 0, m, &cIf_haQKJLV2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_sebDQXLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vHHGPWm8, 0, m, &cDelay_vHHGPWm8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I1x9afDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vHHGPWm8, 0, m, &cDelay_vHHGPWm8_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_FwYlFV8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rCyHkMt2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BLAi2Ap9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hBdnBwWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1Mcq8R1C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_88vreten_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_88vreten_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3dYneT15_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_1Mcq8R1C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_haQKJLV2, 1, m, &cIf_haQKJLV2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BLAi2Ap9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e4eBjdkJ, 0, m, &cIf_e4eBjdkJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rCyHkMt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_e4eBjdkJ, 1, m, &cIf_e4eBjdkJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_QUxvmMA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tkTcaLme, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_CssYs0uX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tkTcaLme, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7MFeNMAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vOOLnmjg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_qwDmHK8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e8McuZGg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_cT4UT1jV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_buceENEz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_buceENEz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8CUkVn00, 1, m, &cDelay_8CUkVn00_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_El5Ghcup_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_8CUkVn00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8CUkVn00, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7MFeNMAL, 0, m, &cIf_7MFeNMAL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_buceENEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8CUkVn00, 0, m, &cDelay_8CUkVn00_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_El5Ghcup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8CUkVn00, 0, m, &cDelay_8CUkVn00_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TY9y4PwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2J6iVKN8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Q2lz2lH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_0U10WIQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZkLekb8W_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ESM3LpWY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ESM3LpWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cT4UT1jV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_ZkLekb8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7MFeNMAL, 1, m, &cIf_7MFeNMAL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2J6iVKN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qwDmHK8M, 1, m, &cIf_qwDmHK8M_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6Q2lz2lH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qwDmHK8M, 0, m, &cIf_qwDmHK8M_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_e8McuZGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4Jn6oseC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vOOLnmjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4Jn6oseC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_RMjAlvMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_22dKEgyu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nhU5Dgtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mnKEsOtk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_tmcV7HRA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HYeWAwSK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HYeWAwSK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dONh5RZq, 1, m, &cDelay_dONh5RZq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yyphIzGI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dONh5RZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dONh5RZq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RMjAlvMC, 0, m, &cIf_RMjAlvMC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HYeWAwSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dONh5RZq, 0, m, &cDelay_dONh5RZq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yyphIzGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dONh5RZq, 0, m, &cDelay_dONh5RZq_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_VwtXZ1IY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HFQDgevI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_muD7lvTf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1geEvd3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0E7puiO6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_54abDm0L_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_54abDm0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tmcV7HRA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0E7puiO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RMjAlvMC, 1, m, &cIf_RMjAlvMC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HFQDgevI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhU5Dgtw, 1, m, &cIf_nhU5Dgtw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_muD7lvTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nhU5Dgtw, 0, m, &cIf_nhU5Dgtw_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_mnKEsOtk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z4qlIadb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_22dKEgyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z4qlIadb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_glhrIJZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dlmvqE3M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jWxCES3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_joe1CWm3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_S91T6XWc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4hQDocXd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4hQDocXd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f2Gj2dre, 1, m, &cDelay_f2Gj2dre_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zBdXmSeP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_f2Gj2dre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f2Gj2dre, m);
  cIf_onMessage(_c, &Context(_c)->cIf_glhrIJZU, 0, m, &cIf_glhrIJZU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4hQDocXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f2Gj2dre, 0, m, &cDelay_f2Gj2dre_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zBdXmSeP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f2Gj2dre, 0, m, &cDelay_f2Gj2dre_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ySML8qTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x7OyQcjP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5wSkil58_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aP54DCez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kAi8xsnX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UqMQ3Udw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UqMQ3Udw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_S91T6XWc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_kAi8xsnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_glhrIJZU, 1, m, &cIf_glhrIJZU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5wSkil58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jWxCES3A, 0, m, &cIf_jWxCES3A_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_x7OyQcjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jWxCES3A, 1, m, &cIf_jWxCES3A_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_joe1CWm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qazBtqO8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_dlmvqE3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qazBtqO8, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_IUC4Ku8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qfJp8KmR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0zvVyJ2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ddkVlvFT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_E5URYKes_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9K24j7V4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9K24j7V4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VgvhFfjr, 1, m, &cDelay_VgvhFfjr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_laCmpXp2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_VgvhFfjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VgvhFfjr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IUC4Ku8S, 0, m, &cIf_IUC4Ku8S_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9K24j7V4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VgvhFfjr, 0, m, &cDelay_VgvhFfjr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_laCmpXp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VgvhFfjr, 0, m, &cDelay_VgvhFfjr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_7pqQHoqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NXW58sIk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OLcVWSs7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AVOVOElC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l2kuNcUH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zUnXRdcy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_l2kuNcUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IUC4Ku8S, 1, m, &cIf_IUC4Ku8S_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zUnXRdcy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_E5URYKes_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NXW58sIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zvVyJ2W, 1, m, &cIf_0zvVyJ2W_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OLcVWSs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0zvVyJ2W, 0, m, &cIf_0zvVyJ2W_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ddkVlvFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ize64v2W, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_qfJp8KmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ize64v2W, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_5DVVNCWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jTYC9Cut_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_XvbOTRII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kpNaBCcX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JCY8emlP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KqnokD3Y_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KqnokD3Y_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ep3iMmK7, 1, m, &cDelay_Ep3iMmK7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zJmz24mC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Ep3iMmK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ep3iMmK7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5DVVNCWN, 0, m, &cIf_5DVVNCWN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KqnokD3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ep3iMmK7, 0, m, &cDelay_Ep3iMmK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zJmz24mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ep3iMmK7, 0, m, &cDelay_Ep3iMmK7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RyNGOdUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xn3Tlh5j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6gzPC7d6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ULlyqILm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z2u8OqJJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RUdUfa9u_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_RUdUfa9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JCY8emlP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_z2u8OqJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5DVVNCWN, 1, m, &cIf_5DVVNCWN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6gzPC7d6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XvbOTRII, 0, m, &cIf_XvbOTRII_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xn3Tlh5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XvbOTRII, 1, m, &cIf_XvbOTRII_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kpNaBCcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JMa0S9kL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jTYC9Cut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JMa0S9kL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_xD7iunjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gSVq84Mk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_B596gPS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ubodoMEX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_kWhkWjLV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_y2lm5Mbe_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_y2lm5Mbe_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5Cnd5CWp, 1, m, &cDelay_5Cnd5CWp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FpvRDo56_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_5Cnd5CWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5Cnd5CWp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xD7iunjh, 0, m, &cIf_xD7iunjh_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_y2lm5Mbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5Cnd5CWp, 0, m, &cDelay_5Cnd5CWp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FpvRDo56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5Cnd5CWp, 0, m, &cDelay_5Cnd5CWp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rxuPQEF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xiWnIH2f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mlf7zlO4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OL1k6b48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lH7ajwT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_702TgTfh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_702TgTfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kWhkWjLV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_0lH7ajwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xD7iunjh, 1, m, &cIf_xD7iunjh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xiWnIH2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B596gPS6, 1, m, &cIf_B596gPS6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Mlf7zlO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_B596gPS6, 0, m, &cIf_B596gPS6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ubodoMEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uD9lu5XG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_gSVq84Mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uD9lu5XG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_9d9887ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ITQj1kRZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BVkLTCQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HcClWwUj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_xuRxMscU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bxYFB4qQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bxYFB4qQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_dQwgrZtX, 1, m, &cDelay_dQwgrZtX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WjNBQ8xL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_dQwgrZtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dQwgrZtX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9d9887ih, 0, m, &cIf_9d9887ih_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bxYFB4qQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQwgrZtX, 0, m, &cDelay_dQwgrZtX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WjNBQ8xL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dQwgrZtX, 0, m, &cDelay_dQwgrZtX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sB8y8hGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J64QQDsM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ue1AVBh6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YsVipkRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eSGegB9y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oCNqJ5Cc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_oCNqJ5Cc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xuRxMscU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_eSGegB9y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9d9887ih, 1, m, &cIf_9d9887ih_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_J64QQDsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BVkLTCQy, 1, m, &cIf_BVkLTCQy_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ue1AVBh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BVkLTCQy, 0, m, &cIf_BVkLTCQy_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HcClWwUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T6FXg4pc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ITQj1kRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T6FXg4pc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_cxbRv2j3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jh0o0zTv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_sQqZpSy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KcRw0TrS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_JaR9DBe7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JOURicOz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JOURicOz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_p3qoeBgc, 1, m, &cDelay_p3qoeBgc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zebZWDWN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_p3qoeBgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_p3qoeBgc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cxbRv2j3, 0, m, &cIf_cxbRv2j3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JOURicOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3qoeBgc, 0, m, &cDelay_p3qoeBgc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zebZWDWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_p3qoeBgc, 0, m, &cDelay_p3qoeBgc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XPojP223_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2uk97222_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GKilY8Yo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_T9QJMdFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pxizyAm7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uFMQ9okt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uFMQ9okt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JaR9DBe7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_pxizyAm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cxbRv2j3, 1, m, &cIf_cxbRv2j3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2uk97222_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sQqZpSy3, 1, m, &cIf_sQqZpSy3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GKilY8Yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sQqZpSy3, 0, m, &cIf_sQqZpSy3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KcRw0TrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9EGUOndU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jh0o0zTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9EGUOndU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_84UPyr7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KJZyGLjw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_OCCNDTqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qPGKBHDb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_KP8u54jr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_njNIllth_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_njNIllth_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vwGYDAEF, 1, m, &cDelay_vwGYDAEF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8vZ94WtM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_vwGYDAEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vwGYDAEF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_84UPyr7s, 0, m, &cIf_84UPyr7s_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_njNIllth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vwGYDAEF, 0, m, &cDelay_vwGYDAEF_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8vZ94WtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vwGYDAEF, 0, m, &cDelay_vwGYDAEF_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_PX5wzph5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zhGM29bs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8OH7IOw0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JMjqS21T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6aaDonhp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ixWJL594_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ixWJL594_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KP8u54jr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_6aaDonhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_84UPyr7s, 1, m, &cIf_84UPyr7s_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8OH7IOw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OCCNDTqR, 0, m, &cIf_OCCNDTqR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zhGM29bs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OCCNDTqR, 1, m, &cIf_OCCNDTqR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qPGKBHDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sTNKlyB0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KJZyGLjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sTNKlyB0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_fvNY8TTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KPBzVrKy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_cVdbTeYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ykdZ9mpl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bRrZeV2r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MxZQXKeJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MxZQXKeJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JP8g93YN, 1, m, &cDelay_JP8g93YN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AOOJUkk6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_JP8g93YN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JP8g93YN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fvNY8TTk, 0, m, &cIf_fvNY8TTk_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MxZQXKeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JP8g93YN, 0, m, &cDelay_JP8g93YN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AOOJUkk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JP8g93YN, 0, m, &cDelay_JP8g93YN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UhzEDBNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_knoHDy6R_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_irjsAFJl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_T91v479n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pfNaM9ri_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_96chxXyd_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_96chxXyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bRrZeV2r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_pfNaM9ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fvNY8TTk, 1, m, &cIf_fvNY8TTk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_knoHDy6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cVdbTeYt, 1, m, &cIf_cVdbTeYt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_irjsAFJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cVdbTeYt, 0, m, &cIf_cVdbTeYt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ykdZ9mpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zPbDm5uu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KPBzVrKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zPbDm5uu, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cQsy0XoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_rze7afYI_sendMessage(_c, 0, m);
  cMsg_Fp911HS4_sendMessage(_c, 0, m);
  cMsg_7lGhGY8s_sendMessage(_c, 0, m);
  cMsg_0rDlz3s6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RzLi3O5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_rze7afYI_sendMessage(_c, 0, m);
  cMsg_FaHbeTfd_sendMessage(_c, 0, m);
  cMsg_ZVB4eH3v_sendMessage(_c, 0, m);
  cMsg_s980HKFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZKse0k6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_BjAd66Pm_sendMessage(_c, 0, m);
  cMsg_FaHbeTfd_sendMessage(_c, 0, m);
  cMsg_0rDlz3s6_sendMessage(_c, 0, m);
  cMsg_XtsPvcrH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zXbkRNIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_BjAd66Pm_sendMessage(_c, 0, m);
  cMsg_8hcLvFEx_sendMessage(_c, 0, m);
  cMsg_7lGhGY8s_sendMessage(_c, 0, m);
  cMsg_ddeHJAY0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WPSZp4nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_SJEnxZYm_sendMessage(_c, 0, m);
  cMsg_s980HKFi_sendMessage(_c, 0, m);
  cMsg_FASCTQDo_sendMessage(_c, 0, m);
  cMsg_7lGhGY8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7JmGJRQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_SJEnxZYm_sendMessage(_c, 0, m);
  cMsg_ddeHJAY0_sendMessage(_c, 0, m);
  cMsg_FaHbeTfd_sendMessage(_c, 0, m);
  cMsg_hZOg5IqN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ug5Jc3np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PoiEWTHe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tPO2mut4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qbhUNPdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PoiEWTHe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tPO2mut4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aaqbm1BQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBdnBwWx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FwYlFV8V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ii24Izfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBdnBwWx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FwYlFV8V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_o4ZPt9Z6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0U10WIQy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TY9y4PwP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_U7Bul8X6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0U10WIQy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TY9y4PwP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rze7afYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ug5Jc3np_sendMessage(_c, 0, m);
  cMsg_Ii24Izfv_sendMessage(_c, 0, m);
  cMsg_U7Bul8X6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BjAd66Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qbhUNPdN_sendMessage(_c, 0, m);
  cMsg_aaqbm1BQ_sendMessage(_c, 0, m);
  cMsg_U7Bul8X6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SJEnxZYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qbhUNPdN_sendMessage(_c, 0, m);
  cMsg_Ii24Izfv_sendMessage(_c, 0, m);
  cMsg_o4ZPt9Z6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_eraoUGZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1geEvd3v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VwtXZ1IY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_c4jAXbo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1geEvd3v_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VwtXZ1IY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nf9dx27u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aP54DCez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ySML8qTM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gbKQEdV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aP54DCez_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ySML8qTM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hEm3vegL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AVOVOElC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7pqQHoqn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x4TiqyQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AVOVOElC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7pqQHoqn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FaHbeTfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_c4jAXbo0_sendMessage(_c, 0, m);
  cMsg_gbKQEdV6_sendMessage(_c, 0, m);
  cMsg_x4TiqyQw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Fp911HS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_c4jAXbo0_sendMessage(_c, 0, m);
  cMsg_Nf9dx27u_sendMessage(_c, 0, m);
  cMsg_hEm3vegL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8hcLvFEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_eraoUGZx_sendMessage(_c, 0, m);
  cMsg_gbKQEdV6_sendMessage(_c, 0, m);
  cMsg_hEm3vegL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_X99W8TSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T9QJMdFH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XPojP223_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hsTDKI6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T9QJMdFH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XPojP223_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Y6VJw88s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JMjqS21T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PX5wzph5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_9ufgwpPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_JMjqS21T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PX5wzph5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_TKd58upE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T91v479n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UhzEDBNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3WPAFOMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_T91v479n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UhzEDBNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ddeHJAY0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_X99W8TSC_sendMessage(_c, 0, m);
  cMsg_9ufgwpPM_sendMessage(_c, 0, m);
  cMsg_3WPAFOMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_s980HKFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_hsTDKI6C_sendMessage(_c, 0, m);
  cMsg_Y6VJw88s_sendMessage(_c, 0, m);
  cMsg_3WPAFOMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0rDlz3s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_hsTDKI6C_sendMessage(_c, 0, m);
  cMsg_9ufgwpPM_sendMessage(_c, 0, m);
  cMsg_TKd58upE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_a1xPrM4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ULlyqILm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RyNGOdUo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_aHk2ti5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ULlyqILm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RyNGOdUo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HnesLRsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OL1k6b48_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rxuPQEF2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6BPj6x2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_OL1k6b48_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rxuPQEF2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pdAsynSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YsVipkRK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sB8y8hGM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Bt5IQ73r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YsVipkRK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sB8y8hGM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7lGhGY8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_aHk2ti5K_sendMessage(_c, 0, m);
  cMsg_6BPj6x2X_sendMessage(_c, 0, m);
  cMsg_Bt5IQ73r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZVB4eH3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_aHk2ti5K_sendMessage(_c, 0, m);
  cMsg_HnesLRsG_sendMessage(_c, 0, m);
  cMsg_pdAsynSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_hZOg5IqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_a1xPrM4Y_sendMessage(_c, 0, m);
  cMsg_HnesLRsG_sendMessage(_c, 0, m);
  cMsg_Bt5IQ73r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FASCTQDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_eraoUGZx_sendMessage(_c, 0, m);
  cMsg_Nf9dx27u_sendMessage(_c, 0, m);
  cMsg_x4TiqyQw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XtsPvcrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_a1xPrM4Y_sendMessage(_c, 0, m);
  cMsg_6BPj6x2X_sendMessage(_c, 0, m);
  cMsg_pdAsynSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_7QvrsioG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6UyChtFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_wmeW9FcR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1lzOfAcP, 0, m, &cSlice_1lzOfAcP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5MllVbvl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_1lzOfAcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M7TqDM6N_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M7TqDM6N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_JlnShxeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M7TqDM6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_M7TqDM6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wSYfhpLs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_yJpUokqE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8txIuNX1, 0, m, &cSlice_8txIuNX1_sendMessage);
      break;
    }
    default: {
      cSwitchcase_gavOtvzw_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_8txIuNX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8kCyZOQ3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8kCyZOQ3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_8fcPB9lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8kCyZOQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_8kCyZOQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_htZVxfkW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_gavOtvzw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_d28fBYjW, 0, m, &cSlice_d28fBYjW_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wmeW9FcR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_d28fBYjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hA0vpe2v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hA0vpe2v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_0Zd8iUT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hA0vpe2v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hA0vpe2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LN32hqag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_5MllVbvl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h0plYzNA, 0, m, &cSlice_h0plYzNA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3ldK29WJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_h0plYzNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KkuxiTqI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KkuxiTqI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_erJn4lnu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KkuxiTqI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_KkuxiTqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qFr5dh61_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_3ldK29WJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UtvLWfyD, 0, m, &cSlice_UtvLWfyD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZJGdanCf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_UtvLWfyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_TCX0gq2x_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_TCX0gq2x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_FyhgiBg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TCX0gq2x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_TCX0gq2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zno71j5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_5eQLIXiL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EyHiyb1T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EyHiyb1T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_QJ7TZCIG, 1, m, &cDelay_QJ7TZCIG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qv3EU4VX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_QJ7TZCIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QJ7TZCIG, m);
  cMsg_ivodHEDB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_EyHiyb1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QJ7TZCIG, 0, m, &cDelay_QJ7TZCIG_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qv3EU4VX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QJ7TZCIG, 0, m, &cDelay_QJ7TZCIG_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_63Q4DWu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wzwdy4Uk, HV_BINOP_SUBTRACT, 0, m, &cBinop_wzwdy4Uk_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_bQr9ZbYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MMXnMDKq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_gGSmJNmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MMXnMDKq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_R3WjskHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_63Q4DWu4, 0, m, &cVar_63Q4DWu4_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_i3U2pxIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgpzoKGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JHiclQzE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k3GAYNcg_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wzwdy4Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_leFpHM92_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_leFpHM92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pQQaL4K9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_pQQaL4K9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_yI3nS0fY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_QsMprVQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zgIERyGN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zRT7p9CL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zRT7p9CL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5MSHBOvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_zgIERyGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bQr9ZbYN, 1, m, &cIf_bQr9ZbYN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GFjlfolI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gGSmJNmM, 1, m, &cIf_gGSmJNmM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_5MSHBOvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_bQr9ZbYN, 0, m, &cIf_bQr9ZbYN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yI3nS0fY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gGSmJNmM, 0, m, &cIf_gGSmJNmM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JHiclQzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wzwdy4Uk, HV_BINOP_SUBTRACT, 1, m, &cBinop_wzwdy4Uk_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DgpzoKGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_k3GAYNcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_63Q4DWu4, 0, m, &cVar_63Q4DWu4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MMXnMDKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c8yfmAjs, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZJGdanCf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Reu8BWBE, 0, m, &cSlice_Reu8BWBE_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Reu8BWBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tXbN3sMj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tXbN3sMj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_CviFCnXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tXbN3sMj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_tXbN3sMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_I60sX4Ap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wALOm2vh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EgpyUGUN, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cZbrNCvt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m2cITV4K, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_5GWfXZTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_R0dyRDkC, 0, m, &cVar_R0dyRDkC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_6UyChtFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fHwuOw26, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_Bs9NbCed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5eQLIXiL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_PzBfWhk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o6qNQI69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ivodHEDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I1hINQIC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_o6qNQI69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I1hINQIC, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eCqBnIGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_JmToApJG_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JmToApJG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L82OIUzB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_L82OIUzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_awocrIq2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_qYZEk4Ag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6wmzxIvB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Rq0rtx9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9RF6NLPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_940ByHM5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rTXjjUdk_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XklQFPRM_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9CPvLXHO_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fA5gCvXD_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TAOH50bj_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Fr9mumha_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_rTXjjUdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yEI4onh7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_XklQFPRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HokBdisj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_9CPvLXHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rduwKBDD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_fA5gCvXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L8i2J3Qs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_TAOH50bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_63B15Y3y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Fr9mumha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ry9gbTbk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_sxUr6pip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_io3g5Mh1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_pMLuWP7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O8GGQpFs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZH1PoFTh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_saXONVEC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_saXONVEC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lpujr0J9, 1, m, &cDelay_lpujr0J9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TwU0WHjb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lpujr0J9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lpujr0J9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sxUr6pip, 0, m, &cIf_sxUr6pip_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_saXONVEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lpujr0J9, 0, m, &cDelay_lpujr0J9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TwU0WHjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lpujr0J9, 0, m, &cDelay_lpujr0J9_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_IvrSrHmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WDOsi7Ap_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_idMWrrqU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_w9WpWxce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IxwkYv2X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G3T5NtKI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_G3T5NtKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZH1PoFTh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_IxwkYv2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sxUr6pip, 1, m, &cIf_sxUr6pip_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WDOsi7Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pMLuWP7X, 1, m, &cIf_pMLuWP7X_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_idMWrrqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pMLuWP7X, 0, m, &cIf_pMLuWP7X_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_O8GGQpFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CyMiW5Ty, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_io3g5Mh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CyMiW5Ty, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_PAL9DjyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_R2O09AWO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_xIXpmbV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RiwkeQGU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_4AwbWbOw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OHaX56D7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OHaX56D7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ETHkvpnm, 1, m, &cDelay_ETHkvpnm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VkhWCZ1e_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ETHkvpnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ETHkvpnm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PAL9DjyC, 0, m, &cIf_PAL9DjyC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OHaX56D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ETHkvpnm, 0, m, &cDelay_ETHkvpnm_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VkhWCZ1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ETHkvpnm, 0, m, &cDelay_ETHkvpnm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_23OJi99Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_te6tgGm4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_awmK3MqV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_o9QI4pZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sYDAgFL4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_txJqfT52_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_txJqfT52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4AwbWbOw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_sYDAgFL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PAL9DjyC, 1, m, &cIf_PAL9DjyC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_awmK3MqV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xIXpmbV5, 0, m, &cIf_xIXpmbV5_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_te6tgGm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xIXpmbV5, 1, m, &cIf_xIXpmbV5_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RiwkeQGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R3BiC2IY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_R2O09AWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R3BiC2IY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_2oJs8Qb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0C87qhjK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YfqYQONa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MSojzOwy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_oaBEP1SD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z3ZgwlvM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z3ZgwlvM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_a6rvpMvA, 1, m, &cDelay_a6rvpMvA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GhMfdSJz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_a6rvpMvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_a6rvpMvA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2oJs8Qb2, 0, m, &cIf_2oJs8Qb2_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_z3ZgwlvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6rvpMvA, 0, m, &cDelay_a6rvpMvA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GhMfdSJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_a6rvpMvA, 0, m, &cDelay_a6rvpMvA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xwoO3YTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P85VLC09_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BPy93xR3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_a3QPy6yB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zF9fisgY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UKp7Tecr_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UKp7Tecr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oaBEP1SD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zF9fisgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2oJs8Qb2, 1, m, &cIf_2oJs8Qb2_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_BPy93xR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YfqYQONa, 0, m, &cIf_YfqYQONa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_P85VLC09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YfqYQONa, 1, m, &cIf_YfqYQONa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MSojzOwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_exEPKAqc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_0C87qhjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_exEPKAqc, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_HIR4fAqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L0iYju8H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_A0ZDaedn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nFn2UPUG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_HkwyOU02_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Yyo1It7H_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Yyo1It7H_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AJQz00FW, 1, m, &cDelay_AJQz00FW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yx1Fq4hX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_AJQz00FW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AJQz00FW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HIR4fAqC, 0, m, &cIf_HIR4fAqC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Yyo1It7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AJQz00FW, 0, m, &cDelay_AJQz00FW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yx1Fq4hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AJQz00FW, 0, m, &cDelay_AJQz00FW_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_JpU4wjeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kh4p550s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s0yRjlbc_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_LOjwNXIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aVgI6wnx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1YiOqRdK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aVgI6wnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HIR4fAqC, 1, m, &cIf_HIR4fAqC_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1YiOqRdK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HkwyOU02_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_s0yRjlbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A0ZDaedn, 0, m, &cIf_A0ZDaedn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Kh4p550s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A0ZDaedn, 1, m, &cIf_A0ZDaedn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nFn2UPUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aLIADwUb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_L0iYju8H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aLIADwUb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Hxeg7pol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QBzDDPfR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4SXsJCNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b4VUJPag_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_24aDwNGV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XWHRFJ4O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XWHRFJ4O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Tegqfuvf, 1, m, &cDelay_Tegqfuvf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bwrsL4ii_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Tegqfuvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Tegqfuvf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Hxeg7pol, 0, m, &cIf_Hxeg7pol_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XWHRFJ4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tegqfuvf, 0, m, &cDelay_Tegqfuvf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_bwrsL4ii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tegqfuvf, 0, m, &cDelay_Tegqfuvf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_d1RyVART_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sVTgfxjf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d0zo78Qv_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GSCUR3z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3QkCaGyw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v6xVghB1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3QkCaGyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hxeg7pol, 1, m, &cIf_Hxeg7pol_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v6xVghB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_24aDwNGV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_d0zo78Qv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4SXsJCNM, 0, m, &cIf_4SXsJCNM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sVTgfxjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4SXsJCNM, 1, m, &cIf_4SXsJCNM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b4VUJPag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rGACZLl2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QBzDDPfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rGACZLl2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_UqpW5c2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iMOSQRaZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_T86f4iJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pKR9dj7Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7VSdQVol_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fDWFp5V3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fDWFp5V3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_K7YDHzu7, 1, m, &cDelay_K7YDHzu7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3yQr4yOy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_K7YDHzu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K7YDHzu7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UqpW5c2V, 0, m, &cIf_UqpW5c2V_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fDWFp5V3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_K7YDHzu7, 0, m, &cDelay_K7YDHzu7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3yQr4yOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K7YDHzu7, 0, m, &cDelay_K7YDHzu7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kFHynBdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IRjiyJJJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iN8dBt2m_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3L6zm4KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rSilo2TO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5pag02G1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rSilo2TO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UqpW5c2V, 1, m, &cIf_UqpW5c2V_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5pag02G1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7VSdQVol_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_iN8dBt2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T86f4iJe, 0, m, &cIf_T86f4iJe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IRjiyJJJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_T86f4iJe, 1, m, &cIf_T86f4iJe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pKR9dj7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kW5mjH5O, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_iMOSQRaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kW5mjH5O, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_57vkF1UH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ye2S9yPo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_tJhcPha0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DcbL52gR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_wQAFhCiL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_amMYG97h_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_amMYG97h_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RkfWWBbj, 1, m, &cDelay_RkfWWBbj_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iVaY1Z4i_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_RkfWWBbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RkfWWBbj, m);
  cIf_onMessage(_c, &Context(_c)->cIf_57vkF1UH, 0, m, &cIf_57vkF1UH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_amMYG97h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RkfWWBbj, 0, m, &cDelay_RkfWWBbj_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_iVaY1Z4i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RkfWWBbj, 0, m, &cDelay_RkfWWBbj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_kuXDKdmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MXwwjg6h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c5F70y1y_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_r86jkJcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bggxShmU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xc8XcR0m_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xc8XcR0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wQAFhCiL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_bggxShmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_57vkF1UH, 1, m, &cIf_57vkF1UH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_c5F70y1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tJhcPha0, 0, m, &cIf_tJhcPha0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_MXwwjg6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tJhcPha0, 1, m, &cIf_tJhcPha0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DcbL52gR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EJfQ5Clt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_ye2S9yPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EJfQ5Clt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_bwn7mFdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3YCb4MpP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_0uIn51nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uz4d4f3D_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_AszuRRm6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8WVhSM9d_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8WVhSM9d_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tl98dd5z, 1, m, &cDelay_tl98dd5z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SSkaTJws_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_tl98dd5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tl98dd5z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bwn7mFdB, 0, m, &cIf_bwn7mFdB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8WVhSM9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tl98dd5z, 0, m, &cDelay_tl98dd5z_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_SSkaTJws_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tl98dd5z, 0, m, &cDelay_tl98dd5z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sZS5FoyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ORciXLy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rcPjiHNh_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_zeggDrpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QxdoFxaT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sRISsPOl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_sRISsPOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AszuRRm6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_QxdoFxaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bwn7mFdB, 1, m, &cIf_bwn7mFdB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ORciXLy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0uIn51nR, 1, m, &cIf_0uIn51nR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rcPjiHNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0uIn51nR, 0, m, &cIf_0uIn51nR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_uz4d4f3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_418mjXL4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_3YCb4MpP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_418mjXL4, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_l7Sdbb1k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9gPLjfMQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_wOG03zqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NyLMAD5l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_7z4pJgnx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LOQhuOdW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LOQhuOdW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1p4wFG2i, 1, m, &cDelay_1p4wFG2i_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DoMFvGgm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_1p4wFG2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1p4wFG2i, m);
  cIf_onMessage(_c, &Context(_c)->cIf_l7Sdbb1k, 0, m, &cIf_l7Sdbb1k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LOQhuOdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1p4wFG2i, 0, m, &cDelay_1p4wFG2i_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DoMFvGgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1p4wFG2i, 0, m, &cDelay_1p4wFG2i_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_McRaNmGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AJMduBhi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ecG6URXD_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AFUNLAAd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_53kUouuK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2zW3pEtn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2zW3pEtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7z4pJgnx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_53kUouuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l7Sdbb1k, 1, m, &cIf_l7Sdbb1k_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ecG6URXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wOG03zqN, 0, m, &cIf_wOG03zqN_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AJMduBhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wOG03zqN, 1, m, &cIf_wOG03zqN_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_NyLMAD5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SpwHMafU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9gPLjfMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SpwHMafU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_foGTEiue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AIfsuI32_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_g41BihN6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0aCIr7tt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_khbqvWG4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MMlTu9kr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MMlTu9kr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wuvvtlaJ, 1, m, &cDelay_wuvvtlaJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3tOTIPkD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wuvvtlaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wuvvtlaJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_foGTEiue, 0, m, &cIf_foGTEiue_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MMlTu9kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wuvvtlaJ, 0, m, &cDelay_wuvvtlaJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3tOTIPkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wuvvtlaJ, 0, m, &cDelay_wuvvtlaJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4IDvIkri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5Pp0IvF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AviaBOuw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_W6Sr1juB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8NCmXsiX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N8HSXBrX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_N8HSXBrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_khbqvWG4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8NCmXsiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_foGTEiue, 1, m, &cIf_foGTEiue_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AviaBOuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g41BihN6, 0, m, &cIf_g41BihN6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v5Pp0IvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g41BihN6, 1, m, &cIf_g41BihN6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0aCIr7tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hjq5E0y3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_AIfsuI32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hjq5E0y3, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_0RZYnIAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LdAtIoYR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_4jSVoP2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nqdebG2p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Px2XLX1W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ju9SDVxx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ju9SDVxx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ynp2dfaf, 1, m, &cDelay_Ynp2dfaf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F4JurEmI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Ynp2dfaf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ynp2dfaf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0RZYnIAT, 0, m, &cIf_0RZYnIAT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ju9SDVxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ynp2dfaf, 0, m, &cDelay_Ynp2dfaf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_F4JurEmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ynp2dfaf, 0, m, &cDelay_Ynp2dfaf_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_REW64mnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zt4EQMpt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DGjHgwxu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_2MlSvpXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s3zKtUw8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VaMfCP0N_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VaMfCP0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Px2XLX1W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_s3zKtUw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0RZYnIAT, 1, m, &cIf_0RZYnIAT_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zt4EQMpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4jSVoP2s, 1, m, &cIf_4jSVoP2s_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DGjHgwxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4jSVoP2s, 0, m, &cIf_4jSVoP2s_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nqdebG2p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xZTykW3a, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_LdAtIoYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xZTykW3a, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_JpcmP4Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_m3X7mdu4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_nTlUAdfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lcr6lq0u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_d2WEEj04_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x7yWnJWS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x7yWnJWS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7iyLxyAS, 1, m, &cDelay_7iyLxyAS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UBogHNId_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7iyLxyAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7iyLxyAS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JpcmP4Sn, 0, m, &cIf_JpcmP4Sn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x7yWnJWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7iyLxyAS, 0, m, &cDelay_7iyLxyAS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UBogHNId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7iyLxyAS, 0, m, &cDelay_7iyLxyAS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hUhhHxXW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Tf1oMUg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pJsCi6fR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_dN550gEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dj0tAcbl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0psgkwfI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_0psgkwfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_d2WEEj04_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_dj0tAcbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JpcmP4Sn, 1, m, &cIf_JpcmP4Sn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pJsCi6fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTlUAdfa, 0, m, &cIf_nTlUAdfa_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8Tf1oMUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTlUAdfa, 1, m, &cIf_nTlUAdfa_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lcr6lq0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NbKpmynk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_m3X7mdu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NbKpmynk, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yEI4onh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_4SFooikL_sendMessage(_c, 0, m);
  cMsg_CZI3SF8Y_sendMessage(_c, 0, m);
  cMsg_7nKVj0La_sendMessage(_c, 0, m);
  cMsg_6hlbnJBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_HokBdisj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_4SFooikL_sendMessage(_c, 0, m);
  cMsg_C2pJCCCT_sendMessage(_c, 0, m);
  cMsg_8NkgUaol_sendMessage(_c, 0, m);
  cMsg_1YjdyeGf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rduwKBDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_0D04XpVO_sendMessage(_c, 0, m);
  cMsg_C2pJCCCT_sendMessage(_c, 0, m);
  cMsg_6hlbnJBg_sendMessage(_c, 0, m);
  cMsg_WqNMyg3T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_L8i2J3Qs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_0D04XpVO_sendMessage(_c, 0, m);
  cMsg_PJ56JDUJ_sendMessage(_c, 0, m);
  cMsg_7nKVj0La_sendMessage(_c, 0, m);
  cMsg_3R95b1o2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_63B15Y3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_F1CTvsTv_sendMessage(_c, 0, m);
  cMsg_1YjdyeGf_sendMessage(_c, 0, m);
  cMsg_QzBjHmHY_sendMessage(_c, 0, m);
  cMsg_7nKVj0La_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ry9gbTbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_F1CTvsTv_sendMessage(_c, 0, m);
  cMsg_3R95b1o2_sendMessage(_c, 0, m);
  cMsg_C2pJCCCT_sendMessage(_c, 0, m);
  cMsg_mnw64EVU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_unjEMi9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w9WpWxce_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IvrSrHmn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DbyNPP06_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w9WpWxce_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IvrSrHmn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_otY3q67E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_o9QI4pZl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_23OJi99Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kIRVTgUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_o9QI4pZl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_23OJi99Y_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_S2X5akGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_a3QPy6yB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xwoO3YTY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wHhzEcOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_a3QPy6yB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xwoO3YTY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_4SFooikL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_unjEMi9N_sendMessage(_c, 0, m);
  cMsg_kIRVTgUL_sendMessage(_c, 0, m);
  cMsg_wHhzEcOg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0D04XpVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_DbyNPP06_sendMessage(_c, 0, m);
  cMsg_otY3q67E_sendMessage(_c, 0, m);
  cMsg_wHhzEcOg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_F1CTvsTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_DbyNPP06_sendMessage(_c, 0, m);
  cMsg_kIRVTgUL_sendMessage(_c, 0, m);
  cMsg_S2X5akGf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_T96slg4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LOjwNXIJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JpU4wjeY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BXMgg4GH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LOjwNXIJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JpU4wjeY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_nIqGBFKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GSCUR3z0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d1RyVART_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ptwoSCMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GSCUR3z0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d1RyVART_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_iO6lpQtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3L6zm4KL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kFHynBdB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LqTccBml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3L6zm4KL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kFHynBdB_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_C2pJCCCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_BXMgg4GH_sendMessage(_c, 0, m);
  cMsg_ptwoSCMU_sendMessage(_c, 0, m);
  cMsg_LqTccBml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CZI3SF8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_BXMgg4GH_sendMessage(_c, 0, m);
  cMsg_nIqGBFKU_sendMessage(_c, 0, m);
  cMsg_iO6lpQtz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PJ56JDUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_T96slg4R_sendMessage(_c, 0, m);
  cMsg_ptwoSCMU_sendMessage(_c, 0, m);
  cMsg_iO6lpQtz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_m2MEtVSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W6Sr1juB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4IDvIkri_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_U6pVdYAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W6Sr1juB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4IDvIkri_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZzjAAu2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2MlSvpXr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_REW64mnZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Go3dWcw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2MlSvpXr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_REW64mnZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rB6H41I2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dN550gEJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hUhhHxXW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_74IglVMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dN550gEJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hUhhHxXW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3R95b1o2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_m2MEtVSN_sendMessage(_c, 0, m);
  cMsg_Go3dWcw8_sendMessage(_c, 0, m);
  cMsg_74IglVMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1YjdyeGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_U6pVdYAV_sendMessage(_c, 0, m);
  cMsg_ZzjAAu2v_sendMessage(_c, 0, m);
  cMsg_74IglVMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6hlbnJBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_U6pVdYAV_sendMessage(_c, 0, m);
  cMsg_Go3dWcw8_sendMessage(_c, 0, m);
  cMsg_rB6H41I2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZZV8WYAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r86jkJcf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kuXDKdmd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_S4Rpyvkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_r86jkJcf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kuXDKdmd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dXjiq98G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zeggDrpt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sZS5FoyM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FVspfoli_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_zeggDrpt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sZS5FoyM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fhEbINrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AFUNLAAd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_McRaNmGc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cJV9aVVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AFUNLAAd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_McRaNmGc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7nKVj0La_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_S4Rpyvkv_sendMessage(_c, 0, m);
  cMsg_FVspfoli_sendMessage(_c, 0, m);
  cMsg_cJV9aVVH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_8NkgUaol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_S4Rpyvkv_sendMessage(_c, 0, m);
  cMsg_dXjiq98G_sendMessage(_c, 0, m);
  cMsg_fhEbINrz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_mnw64EVU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_ZZV8WYAS_sendMessage(_c, 0, m);
  cMsg_dXjiq98G_sendMessage(_c, 0, m);
  cMsg_cJV9aVVH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_QzBjHmHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_T96slg4R_sendMessage(_c, 0, m);
  cMsg_nIqGBFKU_sendMessage(_c, 0, m);
  cMsg_LqTccBml_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_WqNMyg3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_ZZV8WYAS_sendMessage(_c, 0, m);
  cMsg_FVspfoli_sendMessage(_c, 0, m);
  cMsg_fhEbINrz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_x7MxUScd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Mv8J2KmP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_33eL3Djp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kUo6nNi4, 0, m, &cSlice_kUo6nNi4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Fv5hYsCy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_kUo6nNi4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2Gji1pdu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2Gji1pdu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_juMZb31f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2Gji1pdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_2Gji1pdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GunYKtOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_l2ko9CqD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_A0IjdT0O, 0, m, &cSlice_A0IjdT0O_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fpY9N4VE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_A0IjdT0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ybG9vYxU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ybG9vYxU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_N54EWtAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ybG9vYxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_ybG9vYxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7cJPFLJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_fpY9N4VE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QF3O3WQ0, 0, m, &cSlice_QF3O3WQ0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_33eL3Djp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_QF3O3WQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RZiJtV95_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RZiJtV95_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_gNzG9S7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RZiJtV95_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_RZiJtV95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LZnyUgU4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_Fv5hYsCy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vvjNRWHF, 0, m, &cSlice_vvjNRWHF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZtspIR38_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_vvjNRWHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_S8KBHh94_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_S8KBHh94_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_XkuptYd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_S8KBHh94_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_S8KBHh94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BoZk5pq3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ZtspIR38_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kI1ay4s5, 0, m, &cSlice_kI1ay4s5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3aqGOn4f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_kI1ay4s5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qKeu4eiS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qKeu4eiS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_RyOnuE9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qKeu4eiS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_qKeu4eiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IDjPrjDW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ykyUqMEh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2ilVVGvM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2ilVVGvM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ozLQIPvX, 1, m, &cDelay_ozLQIPvX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e9pWi1zb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_ozLQIPvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ozLQIPvX, m);
  cMsg_BnlIUOs1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_2ilVVGvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ozLQIPvX, 0, m, &cDelay_ozLQIPvX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_e9pWi1zb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ozLQIPvX, 0, m, &cDelay_ozLQIPvX_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_aLBKb1Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AkcM5CZQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_AkcM5CZQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_rd0oOUEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_11oGkwkY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2vCI0WIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_11oGkwkY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_pnOBb9pp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aLBKb1Px, 0, m, &cVar_aLBKb1Px_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_wb2g4Nxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O6NAvV1h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EwjvHpvJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5XFqIm5k_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AkcM5CZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PVSskAxf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_PVSskAxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vpY7dpoU_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_vpY7dpoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OF1tZA8V_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_z1dJzEfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDVRg5A5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W7jJlObl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_W7jJlObl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vVhNqojX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_CDVRg5A5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rd0oOUEO, 1, m, &cIf_rd0oOUEO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GCpg6btz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2vCI0WIM, 1, m, &cIf_2vCI0WIM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vVhNqojX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rd0oOUEO, 0, m, &cIf_rd0oOUEO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OF1tZA8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2vCI0WIM, 0, m, &cIf_2vCI0WIM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_EwjvHpvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AkcM5CZQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_AkcM5CZQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5XFqIm5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aLBKb1Px, 0, m, &cVar_aLBKb1Px_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_O6NAvV1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cMsg_11oGkwkY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u64qlEzX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_3aqGOn4f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AHHqoHzF, 0, m, &cSlice_AHHqoHzF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_AHHqoHzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hix881if_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hix881if_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_TGFIx6mA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hix881if_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_hix881if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EI6U3bBE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6wmzxIvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Z3TgquWG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_9RF6NLPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dugLJFVG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_Rk6KfwGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rq0rtx9z, 0, m, &cVar_Rq0rtx9z_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Mv8J2KmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aFqNjtdx, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_GLXUCA2c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ykyUqMEh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_I1PlDqK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q1QxpOPS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BnlIUOs1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tk9dGPwA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Q1QxpOPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Tk9dGPwA, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_6JSDElYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_eBsHyiW3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eBsHyiW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y0yeoATb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_y0yeoATb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d55QO3QF, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_bfJ2kPId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qPQvU4ZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_6iCtxyKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XX9ryO8W, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_7r0KKm9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mdKse8CY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_7jl3LHN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vqgsu7xh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_MISAAxhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_c7QzeRcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_IcsxJYdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NdLaoLMQ, 0, m, &cVar_NdLaoLMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1NMrkca5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rLIB0a7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_57liT5Vm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rpdnjwsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Tg7wP2c4, 0, m, &cVar_Tg7wP2c4_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vd4RWvKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_yciCn4tS, 0, m, &cVar_yciCn4tS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FbRv2PXe, 0, m, &cVar_FbRv2PXe_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_KDHuuBfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IcsxJYdW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_x2DIPTla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_XVT4nL5B, 0, m, &cVar_XVT4nL5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qPQvU4ZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yJpUokqE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_l2ko9CqD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_FAZIntpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_bfJ2kPId, 0, m, &cVar_bfJ2kPId_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_vqgsu7xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ICJ2RqXK_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_v9F8KShz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gczszUX2, 0, m, &cVar_gczszUX2_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_YCtHfCPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IcsxJYdW_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_J2rOmtNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tg7wP2c4, 0, m, &cVar_Tg7wP2c4_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_Qcx2S4Ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JlnShxeG, 0, m, &cVar_JlnShxeG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8fcPB9lu, 0, m, &cVar_8fcPB9lu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0Zd8iUT7, 0, m, &cVar_0Zd8iUT7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_erJn4lnu, 0, m, &cVar_erJn4lnu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FyhgiBg6, 0, m, &cVar_FyhgiBg6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CviFCnXM, 0, m, &cVar_CviFCnXM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_juMZb31f, 0, m, &cVar_juMZb31f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_N54EWtAq, 0, m, &cVar_N54EWtAq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gNzG9S7W, 0, m, &cVar_gNzG9S7W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XkuptYd5, 0, m, &cVar_XkuptYd5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RyOnuE9o, 0, m, &cVar_RyOnuE9o_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TGFIx6mA, 0, m, &cVar_TGFIx6mA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S5K2I1SZ_sendMessage);
  cMsg_x2DIPTla_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_zrnA03Zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XVT4nL5B, 0, m, &cVar_XVT4nL5B_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_vxrZDCPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yciCn4tS, 0, m, &cVar_yciCn4tS_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ehoHayXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FbRv2PXe, 0, m, &cVar_FbRv2PXe_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_wSYfhpLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OfQ9TTsH, 0, m, &cVar_OfQ9TTsH_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_qFr5dh61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7QvrsioG, 0, m, &cVar_7QvrsioG_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_LN32hqag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_5GWfXZTx_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_htZVxfkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lt4hC5xw_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PzBfWhk0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bs9NbCed_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_zno71j5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QsMprVQj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GFjlfolI_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_I60sX4Ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eCqBnIGN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_GunYKtOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qYZEk4Ag, 0, m, &cVar_qYZEk4Ag_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BoZk5pq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x7MxUScd, 0, m, &cVar_x7MxUScd_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_LZnyUgU4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_Rk6KfwGw_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_7cJPFLJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_940ByHM5_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I1PlDqK4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GLXUCA2c_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_IDjPrjDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z1dJzEfl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GCpg6btz_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_EI6U3bBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6JSDElYH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_wdUbwTkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bfJ2kPId, 0, m, &cVar_bfJ2kPId_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_mm89ORnp, VIf(I0));
    __hv_varread_f(&sVarf_Hq7gaEfM, VOf(Bf0));
    __hv_varread_f(&sVarf_Q3EXpJj9, VOf(Bf1));
    __hv_varread_f(&sVarf_1Eomvcyg, VOf(Bf2));
    __hv_varread_f(&sVarf_og96IjJP, VOf(Bf3));
    __hv_varread_f(&sVarf_kYu3u3mF, VOf(Bf4));
    __hv_varread_f(&sVarf_WnwXWvAV, VOf(Bf5));
    __hv_varread_f(&sVarf_1CNtFHgP, VOf(Bf6));
    __hv_varwrite_f(&sVarf_MICFFoUG, VIf(I0));
    __hv_varread_f(&sVarf_OyG3kkGg, VOf(Bf7));
    __hv_line_f(&sLine_9EGUOndU, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_W2Wdjbc5, VOf(Bf9));
    __hv_line_f(&sLine_sTNKlyB0, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_tK1Va8Km, VOf(Bf8));
    __hv_line_f(&sLine_zPbDm5uu, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_og96IjJP, VIf(Bf11));
    __hv_varread_f(&sVarf_MICFFoUG, VOf(Bf11));
    __hv_line_f(&sLine_q8s90BvT, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_z4qlIadb, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_JMa0S9kL, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_kYu3u3mF, VIf(Bf10));
    __hv_line_f(&sLine_tkTcaLme, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_qazBtqO8, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_uD9lu5XG, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_WnwXWvAV, VIf(Bf10));
    __hv_line_f(&sLine_4Jn6oseC, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_ize64v2W, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_T6FXg4pc, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_1CNtFHgP, VIf(Bf10));
    __hv_varwrite_f(&sVarf_OyG3kkGg, VIf(Bf0));
    __hv_varwrite_f(&sVarf_W2Wdjbc5, VIf(Bf1));
    __hv_varwrite_f(&sVarf_tK1Va8Km, VIf(Bf2));
    sEnv_process(this, &sEnv_R3WjskHg, VIf(Bf3), &sEnv_R3WjskHg_sendMessage);
    sEnv_process(this, &sEnv_i3U2pxIk, VIf(I0), &sEnv_i3U2pxIk_sendMessage);
    __hv_line_f(&sLine_c8yfmAjs, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_I1hINQIC, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_awocrIq2, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_Zpq8BXOV, VOf(Bf3));
    __hv_line_f(&sLine_m2cITV4K, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_Hq7gaEfM, VIf(Bf0));
    __hv_varwrite_f(&sVarf_Zpq8BXOV, VIf(Bf4));
    __hv_varwrite_f(&sVarf_BxKHiCWg, VIf(Bf5));
    __hv_varwrite_f(&sVarf_1XkLUkCk, VIf(Bf6));
    __hv_varread_f(&sVarf_1XkLUkCk, VOf(Bf6));
    __hv_line_f(&sLine_fHwuOw26, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_1Eomvcyg, VIf(Bf4));
    __hv_varread_f(&sVarf_BxKHiCWg, VOf(Bf4));
    __hv_line_f(&sLine_EgpyUGUN, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_Q3EXpJj9, VIf(Bf4));
    __hv_varwrite_f(&sVarf_pMT3tlZK, VIf(Bf2));
    __hv_varwrite_f(&sVarf_YswIQyvA, VIf(I1));
    __hv_varread_f(&sVarf_AV6czhmB, VOf(Bf2));
    __hv_varread_f(&sVarf_thkcnA1v, VOf(Bf4));
    __hv_varread_f(&sVarf_r45RSQJv, VOf(Bf0));
    __hv_varread_f(&sVarf_gq6f9FEF, VOf(Bf5));
    __hv_varread_f(&sVarf_K1WRTEG7, VOf(Bf3));
    __hv_varread_f(&sVarf_UnwcyMyj, VOf(Bf6));
    __hv_varread_f(&sVarf_vJqiAhxP, VOf(Bf1));
    __hv_varwrite_f(&sVarf_sAmX5Ntb, VIf(I1));
    __hv_varread_f(&sVarf_Nor596eu, VOf(Bf10));
    __hv_line_f(&sLine_hjq5E0y3, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_ru1dfGpD, VOf(Bf7));
    __hv_line_f(&sLine_xZTykW3a, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_lLIcmiaY, VOf(Bf11));
    __hv_line_f(&sLine_NbKpmynk, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_gq6f9FEF, VIf(Bf12));
    __hv_varread_f(&sVarf_sAmX5Ntb, VOf(Bf12));
    __hv_line_f(&sLine_CyMiW5Ty, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_aLIADwUb, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_EJfQ5Clt, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_K1WRTEG7, VIf(Bf9));
    __hv_line_f(&sLine_R3BiC2IY, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_rGACZLl2, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_418mjXL4, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_UnwcyMyj, VIf(Bf9));
    __hv_line_f(&sLine_exEPKAqc, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_kW5mjH5O, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_SpwHMafU, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_vJqiAhxP, VIf(Bf9));
    __hv_varwrite_f(&sVarf_Nor596eu, VIf(Bf2));
    __hv_varwrite_f(&sVarf_ru1dfGpD, VIf(Bf4));
    __hv_varwrite_f(&sVarf_lLIcmiaY, VIf(Bf0));
    sEnv_process(this, &sEnv_pnOBb9pp, VIf(Bf5), &sEnv_pnOBb9pp_sendMessage);
    sEnv_process(this, &sEnv_wb2g4Nxp, VIf(I1), &sEnv_wb2g4Nxp_sendMessage);
    __hv_line_f(&sLine_u64qlEzX, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_Tk9dGPwA, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_d55QO3QF, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_UWPVx5g6, VOf(Bf5));
    __hv_line_f(&sLine_dugLJFVG, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_AV6czhmB, VIf(Bf2));
    __hv_varwrite_f(&sVarf_UWPVx5g6, VIf(Bf3));
    __hv_varwrite_f(&sVarf_SkuZZTHm, VIf(Bf6));
    __hv_varwrite_f(&sVarf_TUv1AaSE, VIf(Bf1));
    __hv_varread_f(&sVarf_TUv1AaSE, VOf(Bf1));
    __hv_line_f(&sLine_aFqNjtdx, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_r45RSQJv, VIf(Bf3));
    __hv_varread_f(&sVarf_SkuZZTHm, VOf(Bf3));
    __hv_line_f(&sLine_Z3TgquWG, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_thkcnA1v, VIf(Bf3));
    __hv_varwrite_f(&sVarf_hPEvBNeB, VIf(Bf0));
    __hv_varread_f(&sVarf_mm89ORnp, VOf(Bf0));
    __hv_line_f(&sLine_mdKse8CY, VOf(Bf3));
    __hv_varread_f(&sVarf_pMT3tlZK, VOf(Bf2));
    __hv_line_f(&sLine_XX9ryO8W, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_YswIQyvA, VOf(Bf2));
    __hv_varread_f(&sVarf_hPEvBNeB, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
